#!/bin/bash

# Fabrique les exécutables electron/cordova pour une version de Cassiopée $1, les
# distribue sur le serveur $2 dans le dossier $3, et met à jour le fichier releases.json

if [ "$#" -lt 3 ]; then
    echo "usage: $0 X.Y.Z login@server /var/www/releases_dir"
    exit 1
fi

VERSION="$1"
HOST_LOGIN="$2"
RELEASES_DIR="$3"
# RELEASES_DIR="/tmp/cassiopee-releases" # debug
RELEASES_FILE="$RELEASES_DIR/releases.json"
TMP_RELEASES_FILE="tmp-releases.json"

echo "deploy-version.sh: building release for version $VERSION, deploying in $HOST_LOGIN:$RELEASES_DIR"

# build releases
npm run release-all

# update existing releases file

# fetch current releases file
scp "$HOST_LOGIN:$RELEASES_FILE" "./$TMP_RELEASES_FILE"

grep -P "\"latest\": \"$VERSION\"" "$TMP_RELEASES_FILE"

if [[ $? == 0 ]]
then
    echo "$VERSION est déjà la version la plus récente, pas de mise à jour du fichier releases.json"
else
    sed -i -E "s/\"latest\": .+,/\"latest\": \"$VERSION\",/" "$TMP_RELEASES_FILE"
    echo -e "\t\"$VERSION\": {
\t\t\"darwin\": \"Cassiopée-${VERSION}-mac.zip\",
\t\t\"linux\": \"fr.irstea.cassiopee_${VERSION}_amd64.deb\",
\t\t\"win32\": \"Cassiopée Setup $VERSION.exe\",
\t\t\"android\": \"cassiopee-$VERSION.apk\"
\t}," > releases_patch.tmp

    sed -i "/\"latest\": \"$VERSION\",/r releases_patch.tmp" "$TMP_RELEASES_FILE"
    rm releases_patch.tmp
fi

# send updated file, remove local copy
scp "./$TMP_RELEASES_FILE" "$HOST_LOGIN:$RELEASES_FILE"
rm "./$TMP_RELEASES_FILE"

# copy releases to public web directory
scp "release/Cassiopée Setup $VERSION.exe" "release/fr.irstea.cassiopee_${VERSION}_amd64.deb" "release/cassiopee-$VERSION.apk" "release/Cassiopée-${VERSION}-mac.zip" "$HOST_LOGIN:$RELEASES_DIR/"

# symlink "latest" version for each platform
ssh $HOST_LOGIN /bin/bash << EOF
    cd "$RELEASES_DIR"
    ln -sf "Cassiopée Setup $VERSION.exe" "windows-latest.exe"
    ln -sf "fr.irstea.cassiopee_${VERSION}_amd64.deb" "linux-latest.deb"
    ln -sf "Cassiopée-${VERSION}-mac.zip" "macos-latest.zip"
    ln -sf "cassiopee-$VERSION.apk" "android-latest.apk"
EOF
