import { IObservable, Nub, Verificateur, CalculatorType } from "jalhyd";

import { SelectFieldCustom } from "../elements/select-field-custom";
import { SelectField } from '../elements/select-field';
import { FormulaireFixedVar } from "./form-fixedvar";

/**
 * Formulaire pour les Vérificateurs
 */
export class FormulaireVerificateur extends FormulaireFixedVar {

    // interface Observer

    public update(sender: IObservable, data: any) {
        // copied from FormDefinition, to avoid calling super.update() that would trigger an unwanted this.refreshFieldsets();
        if (sender instanceof Nub) {
            switch (data.action) {
                case "resultUpdated":
                    // forward Nub results update notification to FormCompute objects
                    this.reaffectResultComponents();
                    break;
            }
        }
        // copied from FormFixedVar, to avoid calling super.update()
        if (data.action === "propertyChange") {
            this.reset();
        }

        if (sender instanceof SelectFieldCustom) {
            if (sender.id === "select_target_pass" && data.action === "select") {
                // update Verificateur property: Pass to check
                this._currentNub.properties.setPropValue("nubToVerify", data.value ? data.value.value : undefined);
                this.refreshJetTypeSelector();

            } else if (sender.id === "select_species_list" && data.action === "select") {
                // update Verificateur property: Species list (string[])
                (this._currentNub as Verificateur).speciesList = data.value.map((v: any) => v.value);
            }
        }
    }

    protected compute() {
        this.runNubCalc(this.currentNub);
        this.reaffectResultComponents();
        // do not refreshFieldsets() (useless here) or jet type selector's disabled state will be reset
    }

    /**
     * Disables Jet Type selector if target pass is not a Pab
     */
    protected refreshJetTypeSelector() {
        const ntv = (this._currentNub as Verificateur).nubToVerify;
        (this.getFormulaireNodeById("select_pab_jet_type") as SelectField).disabled = ! (ntv !== undefined && ntv.calcType === CalculatorType.Pab);
    }

}
